@@ -35,7 +35,7 @@ class Articles:
         req = self._con.get(url=tmp_url)
         return req.json()
 
-    def get_article_lots(self, p_article_atribut_id: int, p_magatzem_id: [int, None], p_palet_complert: [bool, None]):
+    def get_article_lots(self, p_article_atribut_id: int, p_magatzem_id: int = None, p_palet_complert: bool = None):
         tmp_url = Articles._url_get_articles_lots.format(article_atribut_id=p_article_atribut_id)
         if p_palet_complert is not None:
             if p_palet_complert is True:
@@ -48,7 +48,7 @@ class Articles:
         req = self._con.get(url=tmp_url)
         return req.json()
 
-    def get_article_lot(self, p_article_atribut_id: int, p_lot: str, p_magatzem_id: [int, None], p_palet_complert: [bool, None]):
+    def get_article_lot(self, p_article_atribut_id: int, p_lot: str, p_magatzem_id: int = None, p_palet_complert: bool = None):
         tmp_url = Articles._url_get_article_lot.format(article_atribut_id=p_article_atribut_id, lot=p_lot)
         req = self._con.get(url=tmp_url)
         if p_palet_complert is not None:
@@ -65,7 +65,7 @@ class Articles:
                 result = llista[0]
         return result
 
-    def get_article_lot_id(self, p_article_atribut_id: int, p_lot_id: int, p_magatzem_id: [int, None], p_palet_complert: [bool, None]):
+    def get_article_lot_id(self, p_article_atribut_id: int, p_lot_id: int, p_magatzem_id: int = None, p_palet_complert: bool = None):
         tmp_url = Articles._url_get_article_lot_id.format(article_atribut_id=p_article_atribut_id, id=p_lot_id)
         if p_palet_complert is not None:
             if p_palet_complert is True:
